/*
 Project: Arduino Uno, 3.5" TFT LCD shield
 Function: Displays message. The control pins for the LCD can be
 assigned to any digital or analog pins but we'll use the analog pins
 as this allows us to double up the pins with the touch screen.
// Shield pin usage:
// LCD Data Bit :    7    6    5    4    3    2    1    0
// Digital pin #:    7    6   13    4   11   10    9    8
// Uno port/pin :  PD7  PD6  PB5  PD4  PB3  PB2  PB1  PB0
// Mega port/pin:  PH4  PH3  PB7  PG5  PB5  PB4  PH6  PH5
// Leo port/pin :  PE6  PD7  PC7  PD4  PB7  PB6  PB5  PB4
// Due port/pin : PC23 PC24 PB27 PC26  PD7 PC29 PC21 PC22

// Breakout pin usage:
// LCD Data Bit :   7   6   5   4   3   2   1   0
// Uno dig. pin :   7   6   5   4   3   2   9   8
// Uno port/pin : PD7 PD6 PD5 PD4 PD3 PD2 PB1 PB0
// Mega dig. pin:  29  28  27  26  25  24  23  22
// Mega port/pin: PA7 PA6 PA5 PA4 PA3 PA2 PA1 PA0 (one contiguous PORT)
// Leo dig. pin :   7   6   5   4   3   2   9   8
// Leo port/pin : PE6 PD7 PC6 PD4 PD0 PD1 PB5 PB4
// Due dig. pin :  40  39  38  37  36  35  34  33
// Due port/pin : PC8 PC7 PC6 PC5 PC4 PC3 PC2 PC1 (one contiguous PORT)

IMPORTANT: Adafruit_TFTLCD library must be configured for the 3.5" TFT LCD shield
or the breakout board. See comments about it in Adafruit_TFTLCD.h for proper setup.
 */
//*************************************************************************
#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library
//*************************************************************************
#define LCD_RESET A4 //LCD reset pin attached to analog pin 4 of Arduino Uno board (or reset pin of Arduino Uno board)
#define LCD_CS A3    //LCD chip select pin attached to analog pin 3 of Arduino Uno board
#define LCD_CD A2    //LCD command/data pin (or register select LCD_RS) attached to analog pin 2 of Arduino Uno board
#define LCD_WR A1    //LCD write pin attached to analog pin 1 of Arduino Uno board
#define LCD_RD A0    //LCD read pin attached to analog pin 0 of Arduino Uno board

#define BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF

Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);

void setup() {

  tft.reset();
  uint16_t identifier = tft.readID();
  identifier = 0x9481;
  tft.begin(identifier);
  tft.setRotation(1);
  tft.fillScreen(RED);
  tft.fillScreen(GREEN);
  tft.fillScreen(BLUE);
  tft.fillScreen(BLACK);
  delay(1000);
  tft.setCursor(80, 60);
  tft.setTextColor(WHITE);
  tft.setTextSize(4);
  tft.print("Welcome to ");

  tft.setCursor(240, 130);
  tft.setTextColor(BLUE);
  tft.setTextSize(4);
  tft.print("ACOPTEX!");

  tft.fillRect(80, 200, 321, 60, BLUE);

  tft.setCursor(88, 215);
  tft.setTextColor(WHITE);
  tft.setTextSize(4);
  tft.print("Find out more");

  tft.drawRect(0, 0, 480, 320, WHITE);
  delay(1000);
}

void loop()
{
  tft.fillRect(80, 200, 321, 60, BLACK);
  delay(1000);
  tft.fillRect(80, 200, 321, 60, BLUE);
  tft.setCursor(88, 215);
  tft.setTextColor(WHITE);
  tft.setTextSize(4);
  tft.print("Find out more");
  delay(1000);
}
